@@ -17,11 +17,11 @@ from typing import Any
 
 import pytz
 from dateutil.parser import parse
-from qctrlcommons.graph import Graph
 from qctrlcommons.serializers import DataTypeEncoder
 
 from qctrl.builders.graphql_utils.handlers.base import BaseHandler
 from qctrl.builders.graphql_utils.handlers.mixins import ScalarMixin
+from qctrl.graphs import Graph
 
 
 def _encode_custom_scalar(value: Any) -> Any:
